import sugar
# import algorithm
# import threadpool
# import glob
import os
import strutils
import sequtils
import strformat
import osproc
# import assigns
import unittest
import std/[times, monotimes]
# {.define(shellNoDebugOutput), define(shellNoDebugCommand).}
import shell


proc round(t: Duration): string = t.inMilliseconds.float.`/`(1000.0).formatFloat(ffDecimal,4)

template start_logging  =
  let logging_start_time {.inject.} = getMonoTime()
template elapsed(start:MonoTime): string = round(getMonoTime()-start)
template say(message: varargs[string, `$`]) =
  when (not defined release) or (defined log):
    debugEcho "c " & logging_start_time.elapsed & ": " & message.join " "
template sayA(message: varargs[string, `$`]) =
  debugEcho "c " & logging_start_time.elapsed & ": " & message.join " "
import macros
macro show(vars: varargs[typed]) =
  when (defined release) and (not defined log):
    return
  result = newStmtList()
  for v in vars:
    let n = v.toStrLit
    result.add quote do:
      debugEcho "c " & logging_start_time.elapsed & ": " & `n`, "=", `v`
macro showA(vars: varargs[typed]) =
  result = newStmtList()
  for v in vars:
    let n = v.toStrLit
    result.add quote do:
      debugEcho "c " & logging_start_time.elapsed & ": " & `n`, "=", `v`

type Timer = object
    id: string
    start: MonoTime
    logging_start_time: MonoTime
proc `=destroy`(t: var Timer) =
    let logging_start_time = t.logging_start_time
    sayA t.id & "=" & t.start.elapsed
template time_block(timer_id = "time") {.used.} =
  var timer = Timer(id:timer_id, start:getMonoTime(), logging_start_time:logging_start_time)
  sayA "Start timer: "&timer.id

import nre
proc sub(s, reg: string, def = "NaN"): string {.used.} =
  result = def
  let m = s.find(re(reg))
  if m.isSome(): result = m.get.captures[0].strip

proc cmd(c: string):string {.discardable, used.} = execProcess(c)
proc tmd(c: string):(string, string) {.discardable, used.} =
  let t = getMonoTime()
  let r = execProcess(c)
  return (r, elapsed t)
proc lmd(c: string): int {.discardable, used.} = execCmd(c)
proc smd(c: string): int {.discardable, used.} = lmd(c & " > /dev/null")
proc fmd(c: string): int {.discardable, used.} = lmd(c & " &> /dev/null")
template parallel(n = 4) =
  import taskpools
  let p_num_threads {.inject.} = n
  proc pmd(commands :seq[string], expect = 0): string {.discardable, used.} =
    var tp = Taskpool.new(num_threads = p_num_threads)
    var state = newSeq[FlowVar[int]] commands.len
    for i, c in commands:
      state[i] = tp.spawn lmd c
    for i, s in state:
      let s = sync s
      if s != expect:
        result &= "Error " & $s & ": " & commands[i] & "\n"
    tp.syncAll()
    tp.shutdown()

proc draw(g: openArray[(string,string,string)], name="graph"): string {.discardable.} =
  var c = "echo \"strict digraph  {rankdir=LR;"
  for (u,v,n) in g: c &= &"{u} -> {v} [ label=\"{n}\" ];"
  c &= "}\" | dot -Kdot -Tpdf -q -o" & name & ".pdf"
  echo cmd c
  return "[[file:" & "../assets/" & name & ".pdf]]"
proc draw(g: openArray[(int, int)], name="graph"): string {.discardable.} =
  var c = "echo \"strict digraph  {rankdir=LR;"
  for (u,v) in g: c &= $u & " -> " & $v & " ;"
  c &= "}\" | dot -Kdot -Tpdf -q -o" & name & ".pdf"
  echo cmd c
  return "[[file:" & "../assets/" & name & ".pdf]]"
proc draw(f: openArray[int], e: openArray[int], name="graph"): string {.discardable.} =
  var g : seq[(int, int)]
  for u in 0..<high f:
    for v in e[f[u]..<f[u+1]]:
      g.add (u,v)
  draw g

proc org(things: varargs[string, `$`]) {.used.} =
  var output = "| "
  for thing in things:
    output &= thing & " | "
  output = output[0..^1]
  echo output

proc org_arr(things: openArray[int]) {.used.} =
  var output = "| "
  for thing in things:
    output &= $thing & " | "
  output = output[0..^1]
  echo output

proc `=<`(l: var int, r: int) {.used.} = l = l.min r
proc `min=`(l: var int, r: int): bool {.discardable, used.} =
    if l > r:
      l = r
      return true
proc `max=`(l: var int, r: int): bool {.discardable, used.} =
    if l < r:
      l = r
      return true
func take[T](a: openArray[T], indeces: openArray[int]): seq[T] {.used.} = indeces.mapIt a[it]

iterator product[T1, T2](a: openArray[T1]; b: openArray[T2]): tuple[a: T1, b: T2] {.used.} =
  for x in a:
    for y in b:
      yield (x, y)

proc rorg(path: string): seq[seq[string]] {.used.} =
  path.readfile.strip.splitlines.
    mapit it.split("|")[1..^2].mapit(it.strip)

proc `[]`[T](xs: openarray[seq[T]], p: (int, int)): T {.used.} = xs[p[0]][p[1]]
proc `[]=`[T](xs: var openarray[seq[T]], p: (int, int), v: T) {.used.} = xs[p[0]][p[1]] = v

proc `[]`[T](xs: openarray[seq[T]], p: seq[int]): T {.used.} = xs[p[0]][p[1]]
proc `[]=`[T](xs: var openarray[seq[T]], p: seq[int], v: T) {.used.} = xs[p[0]][p[1]] = v

import uuids
const temp_dir = getTempDir()/"nfuzz"
proc temp_id: string = temp_dir / $genUUID()
var temp_files: seq[string]
proc temp(ext=""): string {.used.} =
  # let p = getTempDir()/"nfuzz"/getAppFilename().extractFilename/($getCurrentProcessId())
  result = temp_id().addFileExt ext
  temp_files.add result
  assert not fileExists result
template temp_setup =
  removeDir temp_dir
  createDir temp_dir
  # defer: removeDir temp_dir
proc temp_clear() {.noconv.} =
  for f in temp_files: removeFile f
  temp_files.setLen 0
setControlCHook temp_clear

const fuzzing_threads = 8
var fuzzing_runs: array[fuzzing_threads, int]
var fuzzing_stopped: array[fuzzing_threads, bool]
template fuzz(run: untyped) =
  proc fuzz_while(id:int): void =
    while true:
      run
      inc fuzzing_runs[id]
    fuzzing_stopped[id] = true
  echo &"Running fuzzer with {fuzzing_threads} threads... "
  for id in 0..<fuzzing_threads: spawn fuzz_while id
  while true:
    sleep 2000
    stdout.write "\rfuzzed " & $(fuzzing_runs.foldl a+b)
    stdout.flushFile
    if fuzzing_stopped.allIt it: break
proc thisFails(s: string, t=0): bool =
  let timeout = if t == 0: "" else: &"timeout {t} "
  smd(timeout & getAppFilename() & " " & s) != 0

var c = commandLineParams()
